 /**
 * The MySensors Arduino library handles the wireless radio link and protocol
 * between your home built sensors/actuators and HA controller of choice.
 * The sensors forms a self healing radio network with optional repeaters. Each
 * repeater and gateway builds a routing tables in EEPROM which keeps track of the
 * network topology allowing messages to be routed to nodes.
 *
 * Created by Henrik Ekblad <henrik.ekblad@mysensors.org>
 * Copyright (C) 2013-2015 Sensnology AB
 * Full contributor list: https://github.com/mysensors/Arduino/graphs/contributors
 *
 * Documentation: http://www.mysensors.org
 * Support Forum: http://forum.mysensors.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 *******************************
 *
 * DESCRIPTION
 * The ArduinoGateway prints data received from sensors on the serial link.
 * The gateway accepts input on seral which will be sent out on radio network.
 *
 * The GW code is designed for Arduino Nano 328p / 16MHz
 *
 * Wire connections (OPTIONAL):
 * - Inclusion button should be connected between digital pin 3 and GND
 * - RX/TX/ERR leds need to be connected between +5V (anode) and digital pin 6/5/4 with resistor 270-330R in a series
 *
 * LEDs (OPTIONAL):
 * - To use the feature, uncomment MY_LEDS_BLINKING_FEATURE in MyConfig.h
 * - RX (green) - blink fast on radio message recieved. In inclusion mode will blink fast only on presentation recieved
 * - TX (yellow) - blink fast on radio message transmitted. In inclusion mode will blink slowly
 * - ERR (red) - fast blink on error during transmission error or recieve crc error
 *
 */

/*************** SETTINGS ***************/

// Enable debug prints to serial monitor
#define MY_DEBUG

{% if radio is equalto 'NRF24' %}
// Enable and select radio type attached
#define MY_RADIO_NRF24
// Set LOW transmit power level as default, if you have an amplified NRF-module and
// power your radio separately with a good regulator you can turn up PA level.
#define MY_RF24_PA_LEVEL RF24_PA_LOW
{% endif %}

{% if type is equalto 'serial' %}
// Enable serial gateway
#define MY_GATEWAY_SERIAL
{% endif %}

/***** BLINKING LEDS SETTINGS *****/
// Flash leds on rx/tx/err
#define MY_LEDS_BLINKING_FEATURE
// Set blinking period
#define MY_DEFAULT_LED_BLINK_PERIOD 300

#define MY_DEFAULT_ERR_LED_PIN 4  // Error led pin
#define MY_DEFAULT_RX_LED_PIN  6  // Receive led pin
#define MY_DEFAULT_TX_LED_PIN  5  // the PCB, on board LED
/**********************************/

#include <SPI.h>
#include <MySensor.h>

{% if name or version %}
/********* SKETCH SETTINGS ********/
#define SKETCH_NAME     "{{ name }}"
#define SKETCH_VERSION  "{{ version }}"
/**********************************/
{% endif %}

/*********** END SETTINGS ***************/

void setup() {
    // Setup locally attached sensors
}

void presentation() {
    /*
     * This function is called at the start of the node
     * and every time the node receives an I_PRESENTATION message.
     * You must present all your node's child here
     */
}

void loop() {
    // Send locally attached sensor data here
}

void receive(const MyMessage &message) {
  /*
   * This function is called every time the node receives an message.
   * So, it is here that you must filter your messages and decide how to react.
   * Since you may setup just a Gateway, you don't need to keep this function.
   * However, you want to treat this Gateway as a common node with sensors, you must
   * implement this function.
   * Enjoy and becareful! With great power comes great responsabilities!
   */
}